/**
  TMR4 Generated Driver File

  @Company
    Microchip Technology Inc.

  @File Name
    tmr4.c

  @Summary
    This is the generated driver implementation file for the TMR4 driver using PIC10 / PIC12 / PIC16 / PIC18 MCUs

  @Description
    This source file provides APIs for TMR4.
    Generation Information :
        Product Revision  :  PIC10 / PIC12 / PIC16 / PIC18 MCUs - 1.65
        Device            :  PIC16F18325
        Driver Version    :  2.00
    The generated drivers are tested against the following:
        Compiler          :  XC8 1.45
        MPLAB 	          :  MPLAB X 4.10
*/

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

/**
  Section: Included Files
*/

#include <xc.h>
#include "tmr4.h"
#include "mcc.h"

/**
  Section: Global Variables Definitions
*/
unsigned int LowWidth, HighWidth, Duty;
extern unsigned char BitFlag, BitCount;
extern unsigned char State, MainState, Logic, RptFlag ,Flag;

void (*TMR4_InterruptHandler)(void);

/**
  Section: TMR4 APIs
*/

void TMR4_Initialize(void)
{
    // Set TMR4 to the options selected in the User Interface

    // PR4 99; 
    PR4 = 0x63;

    // TMR4 0; 
    TMR4 = 0x00;

    // Clearing IF flag before enabling the interrupt.
    PIR2bits.TMR4IF = 0;

    // Enabling TMR4 interrupt.
    PIE2bits.TMR4IE = 1;

    // Set Default Interrupt Handler
    TMR4_SetInterruptHandler(TMR4_DefaultInterruptHandler);

    // T4CKPS 1:1; T4OUTPS 1:8; TMR4ON on; 
    T4CON = 0x3C;
}

void TMR4_StartTimer(void)
{
    // Start the Timer by writing to TMRxON bit
    T4CONbits.TMR4ON = 1;
}

void TMR4_StopTimer(void)
{
    // Stop the Timer by writing to TMRxON bit
    T4CONbits.TMR4ON = 0;
}

uint8_t TMR4_ReadTimer(void)
{
    uint8_t readVal;

    readVal = TMR4;

    return readVal;
}

void TMR4_WriteTimer(uint8_t timerVal)
{
    // Write to the Timer4 register
    TMR4 = timerVal;
}

void TMR4_LoadPeriodRegister(uint8_t periodVal)
{
   PR4 = periodVal;
}

void TMR4_ISR(void)
{

    // clear the TMR4 interrupt flag
    PIR2bits.TMR4IF = 0;

    // ticker function call;
    // ticker is 1 -> Callback function gets called everytime this ISR executes
    TMR4_CallBack();
}

void TMR4_CallBack(void)
{
    // Add your custom callback code here
    switch(State){                          // State0̏ꍇ
        case 0:                             // [_R[h
            if(IR_GetValue() == 0){         // Low̏ꍇ
                LowWidth++;                 // LowJE^Abv
            }
            else{                           // High̏ꍇ
                if(LowWidth > 80){          // [_R[h̏ꍇ
                    LowWidth = 0;           // JE^Zbg
                    HighWidth = 0;
                    State = 1;              //Xe[gAbv
                }
            }
            break;
        case 1:                             // [_R[h㔼̏
            if(IR_GetValue() == 1){         // High̏ꍇ
                HighWidth++;                // HighJE^Abv
            }
            else{                           // Low̏ꍇ
                if(HighWidth > 40){         // ʏt[̏ꍇ
                    RptFlag = 0;            // s[gtOZbg
                    State = 3;              // f[^M
                    MainState = 1;          // CXe[gAbv
                }
                else if(HighWidth > 20){    // s[gt[̏ꍇ
                    RptFlag = 1;            // s[gtOZbg
                    State = 2;              // XgbvrbgXLbv
                    MainState = 1;          // CXe[gAbv
                }
                else{                       // ǂłȂꍇ
                    RptFlag = 0;            // tONA
                    State = 0;              // Xe[g
                }
                LowWidth = 0;               // pXJE^Zbg
                HighWidth = 0;              
            }
            break;
        case 2:                             // s[g̃XgbvrbgXLbv
            if(IR_GetValue() == 0)          // Low̏ꍇ
                LowWidth++;                 // LowJE^Abv
            else{
                LowWidth = 0;               // XgbvrbgXLbv
                HighWidth = 0;
                State = 0;                  // Xe[g                   
            }
            break;
        case 3:                             // rbgf[^̍ŏLoẘmF
            if(IR_GetValue() == 0){         // Low̏ꍇ
                LowWidth++;                 // rbgŏLow
            }
            else{                           // High̏ꍇ
                if(LowWidth > 3)            // LowrbgmFłꍇ
                    State = 4;              // 0,1菈
                else                        // Lows̏ꍇ
                    State = 0;              // G[Ƃď
                LowWidth = 0;
                HighWidth = 0;
            }
            break;
        case 4:                             // f[^rbg0,1
            if(IR_GetValue() == 1){         // High̏ꍇ
                HighWidth++;
            }
            else{                           // Low̏ꍇ
                if(HighWidth > 12)          // Highꍇ
                    Logic = 1;              // _u1vƂ
                else                        // HighZꍇ
                    Logic = 0;              // _u0vƂ
                HighWidth = 0;              // rbgJEgZbg
                LowWidth = 0;
                BitFlag = 1;                // rbgMtOZbg
                State = 3;                  // ÕXe[g
            }     
            break;
    }     
    
    
    // this code executes every TMR4_INTERRUPT_TICKER_FACTOR periods of TMR4
    if(TMR4_InterruptHandler)
    {
        TMR4_InterruptHandler();
    }
}

void TMR4_SetInterruptHandler(void (* InterruptHandler)(void)){
    TMR4_InterruptHandler = InterruptHandler;
}

void TMR4_DefaultInterruptHandler(void){
    // add your TMR4 interrupt custom code
    // or set custom function using TMR4_SetInterruptHandler()
}

/**
  End of File
*/